<div id="div_{{ field.auto_id }}">
    {{ field.label_tag }}
    <div class="content">{{ field.form.instance.template.message|safe }}</div>
    <input type="hidden" name="{{ field.html_name }}" value="{% if field.value %}{{ field.value }}{% endif %}">
</div>
