{% extends "po_projects/base.html" %}
{% load i18n crispy_forms_tags %}{% load url from future %}
{% block title %}{% trans "Create a new project" %}{% endblock %}

{% block content %}
    <h2>{% trans "Create a new project" %}</h2>
    
    {% crispy form %}
{% endblock %}
