{% extends "skeleton.html" %}
{% load i18n %}

{% block base_content %}<div class="row po_projects">
    <div class="small-12 columns">
        {% block content %}{% endblock %}
    </div>
</div>{% endblock %}
