{% extends "po_projects/base.html" %}
{% load i18n crispy_forms_tags %}{% load url from future %}
{% block title %}{% trans "Create a new project" %}{% endblock %}

{% block content %}
    <h2><small>{% trans "Project" %}</small> {{ project.name }}</h2>
    
    <hr>
    <h3>{% trans "Project translations" %}</h3>
    <ul class="disc">{% for item in project.catalog_set.all %}
        <li>
            <a href="{% url 'po_projects:catalog-details' slug=project.slug locale=item.locale %}">{{ item }}</a>
        </li>
    {% empty %}
        <li>There is no translation yet</li>
    {% endfor %}</ul>
    
    <a href="{% url 'po_projects:project-download' slug=project.slug %}" class="button">{% trans "Download archive" %}</a>
    
    <hr>
    <h4>{% trans "Add new" %}</h4>
    {% crispy form %}
    
    <hr>
    <h3>{% trans "Messages to translate" %} ({{ project.templatemsg_set.count }})</h3>
    <ul class="disc">{% for item in project.templatemsg_set.all %}
        <li>
            <blockquote>
                <p>{{ item.message|safe }}
                {% comment %}<cite>{{ item.locations }}</cite>{% endcomment %}</p>
            </blockquote>
        </li>
    {% endfor %}</ul>
{% endblock %}
